@@ -10,7 +10,7 @@ require Exporter;
 
 our @ISA = qw(Exporter AptPkg::hash);
 our @EXPORT = ();
-our $VERSION = 1.25;
+our $VERSION = '1.26';
 
 sub new
 {
@@ -229,7 +229,7 @@ our @ISA = qw(AptPkg::hash::method::iter);
 package AptPkg::Cache::VerFile;
 
 our @ISA = qw(AptPkg::hash::method);
-our @KEYS = qw(File Index Offset Size);
+our @KEYS = qw(File Index Offset);
 
 sub File { AptPkg::Cache::_make_class shift, 'AptPkg::Cache::PkgFile' }
 
@@ -578,9 +578,7 @@ An AptPkg::Cache::PkgFile object describing the packages file.
 
 =item Offset
 
-=item Size
-
-The byte offset and length of the entry in the file.
+The byte offset of the entry in the file.
 
 =item Index
 
